@@ -7,6 +7,16 @@ import sys
 import pkgutil
 import re
 
+# determine platform at runtime
+system = platform.system()
+#arch, _ = platform.architecture()
+if system == 'Linux':
+    os='linux'
+if system == 'Windows':
+    os='win'
+if system == 'Darwin':
+    os='mac'
+
 # Adds a line to some *data file.
 def add_keyword(keyword, filename:str, params=None):
     data_file = open(filename, "a")
@@ -36,7 +46,7 @@ def gmin():
         # write output to file
         f = open("gmin_output.txt", "w")
         # execute GMIN binary as defined by setup.py for correct OS
-        subprocess.call('GMIN', stdout=f)
+        subprocess.call(f'bin/{os}/GMIN', stdout=f)
     else:
         print('Data or coords file are missing')		
 
@@ -46,7 +56,7 @@ def optim(outfile='optim_output.txt'):
         # write output to file
         f = open(outfile, "w")
         # execute OPTIM binary as defined by setup.py for correct OS
-        subprocess.call('OPTIM', stdout=f)
+        subprocess.call(f'bin/{os}/OPTIM', stdout=f)
     else:
         print('odata file is missing')
 
@@ -56,7 +66,7 @@ def pathsample():
         # write output to file
         f = open("pathsample_output.txt", "w")
         # execute PS binary as defined by setup.py for correct OS
-        subprocess.call('PATHSAMPLE', stdout=f)
+        subprocess.call(f'bin/{os}/PATHSAMPLE', stdout=f)
     else:
         print('pathdata file is missing')
 
